'''
Copyright 2017, Fujitsu Network Communications, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''

""" Wapp Driver """

from warrior.WarriorCore import kw_driver
import warriorwapp.Actions.WappActions.WappReportingActions


def main(keyword, data_repository, args_repository):
    """Import all actions related to wapp driver and call the driver Utils
    to execute a keyword """
    # Declare a list of packages to be used by this driver,
    # if you want to add more packages import them outside the main function
    # and then add them to the package_list below
    package_list = [warriorwapp.Actions.WappActions.WappReportingActions]

    return kw_driver.execute_keyword(keyword, data_repository, args_repository, package_list)



'''
Copyright 2017, Fujitsu Network Communications, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''

import datetime
import multiprocessing
from warrior.Framework.Utils import config_Utils
from warrior.WarriorCore.Classes.warmock_class import mockready
from warrior.Framework.Utils.data_Utils import get_object_from_datarepository, get_credentials


class CWPluginActions(object):
    """ Class with kw providing utilities that connect Warrior to Wapps """

    def __init__(self):
        """
        constructor
        """
        self.resultfile = config_Utils.resultfile
        self.datafile = config_Utils.datafile
        self.logsdir = config_Utils.logsdir
        self.filename = config_Utils.filename
        self.logfile = config_Utils.logfile

    @mockready
    def report_ne_status_to_katana(self, system_name):
        """
            write the ne execution result to the live html obj
        """
        live_html_obj = get_object_from_datarepository("live_html_dict")
        cred = get_credentials(self.datafile, system_name)
        status = False
        if live_html_obj and isinstance(live_html_obj.get("livehtmllocn", None),
                                        multiprocessing.managers.DictProxy):
            result = True
            for key, val in config_Utils.data_repository.items():
                if key.startswith("step-") and key.endswith("_status"):
                    if isinstance(val, bool) and result != "ERROR":
                        result &= val
                    else:
                        result = "ERROR"
            # In order to share data between process, have to use the multiprocess
            # manager dict to store it
            # Cannot simply create a new dict and assign it to the live_html_obj
            tmp = live_html_obj["livehtmllocn"]["system_result"]
            tmp[cred["circuit_id"]] = tmp.get(cred["circuit_id"], {})
            tmp[cred["circuit_id"]][cred["id"]] = (
                result, datetime.datetime.now().replace(microsecond=0),
                str(self.logfile)[:-4] + "_consoleLogs.log")
            live_html_obj["livehtmllocn"]["system_result"] = tmp
            status = True
        return status



'''
Copyright 2017, Fujitsu Network Communications, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
'''
from setuptools import setup, find_packages

PACKAGE_NAME = "warriorwapp"
PACKAGE_VERSION = "1.0.0"

setup(
    name=PACKAGE_NAME,
    version=PACKAGE_VERSION,
    author="warriorteam",
    author_email='frameworkwarrior@gmail.com',
    scripts=[],
    packages=find_packages(),
    package_data={'':['**/*', '*']},
    include_package_data=True,
    long_description= "wapp_driver package for warrior framework",
    description="Warrior Framework is an open source Automation Framework",
    url="https://github.com/warriorframework/warriorframework_py3",
    project_urls={
        "Documentation": "http://warriorframework.org/",
        "Source Code": "https://github.com/warriorframework/warriorframework_py3",
    },
    classifiers=['Development Status :: 5 - Production/Stable',
                 'License :: OSI Approved :: Apache Software License',
                 'Programming Language :: Python :: 3.6',],
    install_requires=[]

)
